Alias — Poezio 0.9-dev documentation

# Alias

## Usage

This plugin defines two new global commands: /alias and /unalias.

/alias

  Usage: `/alias <name> <command> [args]`

  This command will create a new command, named `<name>` (and callable with `/name`), that runs `/command`, with `[args]` as fixed args for the command. When you run the alias, you can also pass parameters to it, that will be given to the original command.

  Example:

      /alias toto say koin

  Will bind `/say koin` to `/toto`, so this alias will work in any Chat tab. If someone calls it with

      /toto koin

  Poezio will then execute `/say koin koin`.

  Also, you can rebind arguments arbitrarily, with the `{}` placeholder. For example,

      /alias toto say {} le {}
      /toto loulou coucou

  Will execute `/say loulou le coucou`, because the `{}` are replaced with the command args, in the order they are given.

  Extra args are still added at the end of the command if provided (args used for the formatting are only used for the formatting).

/unalias

  Usage: `/unalias <name>`

  This command removes a defined alias.

## Config

The aliases are stored inside the configuration file for the plugin. You can either use the above commands or write it manually, and it will be read when the plugin is loaded.

Example of the syntax:

    [alias]
    toto = say {} le {}
    j = join {}@conference.jabber.org/nick
    jp = say je proteste